==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/safariservices/SFSafariViewControllerDelegateAdapter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.safariservices;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.uikit.*;
/*</imports>*/

/*<javadoc>*/
/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/SFSafariViewControllerDelegateAdapter/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*/implements SFSafariViewControllerDelegate/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*//*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @NotImplemented("safariViewController:activityItemsForURL:title:")
    public NSArray<UIActivity> getActivityItems(SFSafariViewController controller, NSURL URL, String title) { return null; }
    @NotImplemented("safariViewControllerDidFinish:")
    public void didFinish(SFSafariViewController controller) {}
    @NotImplemented("safariViewController:didCompleteInitialLoad:")
    public void didCompleteInitialLoad(SFSafariViewController controller, boolean didLoadSuccessfully) {}
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/safariservices/SFSafariViewControllerDelegateAdapter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.safariservices;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.uikit.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 9.0 and later.
 */
/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/SFSafariViewControllerDelegateAdapter/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*/implements SFSafariViewControllerDelegate/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*//*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @NotImplemented("safariViewController:activityItemsForURL:title:")
    public NSArray<UIActivity> getActivityItems(SFSafariViewController controller, NSURL URL, String title) { return null; }
    /**
     * @since Available in iOS 11.0 and later.
     */
    @NotImplemented("safariViewController:excludedActivityTypesForURL:title:")
    public NSArray<NSString> excludedActivityTypesForURL(SFSafariViewController controller, NSURL URL, String title) { return null; }
    @NotImplemented("safariViewControllerDidFinish:")
    public void didFinish(SFSafariViewController controller) {}
    @NotImplemented("safariViewController:didCompleteInitialLoad:")
    public void didCompleteInitialLoad(SFSafariViewController controller, boolean didLoadSuccessfully) {}
    /**
     * @since Available in iOS 11.0 and later.
     */
    @NotImplemented("safariViewController:initialLoadDidRedirectToURL:")
    public void initialLoadDidRedirectToURL(SFSafariViewController controller, NSURL URL) {}
    /**
     * @since Available in iOS 14.0 and later.
     */
    @NotImplemented("safariViewControllerWillOpenInBrowser:")
    public void safariViewControllerWillOpenInBrowser(SFSafariViewController controller) {}
    /*</methods>*/
}
